@@ -274,10 +274,15 @@ class CoverageConfig(TConfigurable, TPluginConfig):
         "patch",
     }
 
+    # File paths to make absolute during serialization.
+    # The pairs are (config_key, must_exist).
     SERIALIZE_ABSPATH = {
-        "data_file",
-        "debug_file",
-        "source_dirs",
+        ("data_file", False),
+        ("debug_file", False),
+        # `source` can be directories or modules, so don't abspath it if it
+        # doesn't exist.
+        ("source", True),
+        ("source_dirs", False),
     }
 
     def from_args(self, **kwargs: TConfigValueIn) -> None:
@@ -563,27 +568,44 @@ class CoverageConfig(TConfigurable, TPluginConfig):
         return human_sorted_items((k, v) for k, v in self.__dict__.items() if not k.startswith("_"))
 
     def serialize(self) -> str:
-        """Convert to a string that can be ingested with `deserialize_config`.
+        """Convert to a string that can be ingested with `deserialize`.
 
         File paths used by `coverage run` are made absolute to ensure the
         deserialized config will refer to the same files.
         """
         data = {k: v for k, v in self.__dict__.items() if not k.startswith("_")}
-        for k in self.SERIALIZE_ABSPATH:
+        for k, must_exist in self.SERIALIZE_ABSPATH:
+            abs_fn = abs_path_if_exists if must_exist else os.path.abspath
             v = data[k]
             if isinstance(v, list):
-                v = list(map(os.path.abspath, v))
+                v = list(map(abs_fn, v))
             elif isinstance(v, str):
-                v = os.path.abspath(v)
+                v = abs_fn(v)
             data[k] = v
         return base64.b64encode(json.dumps(data).encode()).decode()
 
+    @classmethod
+    def deserialize(cls, config_str: str) -> CoverageConfig:
+        """Take a string from `serialize`, and make a CoverageConfig."""
+        data = json.loads(base64.b64decode(config_str.encode()).decode())
+        config = cls()
+        config.__dict__.update(data)
+        return config
+
 
 def process_file_value(path: str) -> str:
     """Make adjustments to a file path to make it usable."""
     return os.path.expanduser(path)
 
 
+def abs_path_if_exists(path: str) -> str:
+    """os.path.abspath, but only if the path exists."""
+    if os.path.exists(path):
+        return os.path.abspath(path)
+    else:
+        return path
+
+
 def process_regexlist(name: str, option: str, values: list[str]) -> list[str]:
     """Check the values in a regex list and keep the non-blank ones."""
     value_list = []
@@ -693,11 +715,3 @@ def read_coverage_config(
     config.post_process()
 
     return config
-
-
-def deserialize_config(config_str: str) -> CoverageConfig:
-    """Take a string from CoverageConfig.serialize, and make a CoverageConfig."""
-    data = json.loads(base64.b64decode(config_str.encode()).decode())
-    config = CoverageConfig()
-    config.__dict__.update(data)
-    return config
